#############################################################################################################
# PREAMBLE
#############################################################################################################

library(xlsx)       # read/write MS Excel
library(igraph)     # building and analyzing network models
library(psych)      # analysis linear correlation of parameters

library(ape)        # tree manipulation
library(paleotree)  # tree calibration
library(phytools)   # tree manipulation
library(geoscale)   # plot tree
library(strap)      # plot tree

library(ggplot2)    # plot environment
library(ggbiplot)   # plot PCA; require(devtools); install_github("vqv/ggbiplot")
library(ggrepel)    # plot text labels
library(gridExtra)  # plot multipanel

library(vegan)      # analysis PERMANOVA

library(evomap)     # analysis statistical tests with phylogeny
library(geiger)     # analysis disparity through time
library(metap)      # analysis combining p-values
library(mvMORPH)    # analysis evolutionary model fitting
library(nlme)       # analysis statistical tests
library(surface)    # analysis evolutionary model estimation



library(GGally)     # plot networks; install.packages("GGally")



# Variables
parameter_names<-c("Nodes","Links","Density","Clustering","Path_length","Heterogeneity","Assortativity","Parcellation")
networks<-c("Mus PECA","Didelphis PECA","Iguana PECA","Sphenodon PECA","Hyloplesion PECA","Pantylus PECA","Westlothiana PECA","Seymouria PECA","Ambystoma PECA","Salamandra PECA","Celtedens PECA","Eryops PECA","Balanerpeton PECA","Tulerpeton PECA","Ichthyostega PECA","Acanthostega PECA","Tiktaalik PECA","Panderichthys PECA","Mandageria PECA","Cabonnichthys PECA","Eusthenopteron PECA","Gogonasus PECA","Sterropteryon PECA","Sauripterus PECA","Neoceratodus PECA","Latimeria PECA","Polypterus PECA",
            "Mus PELA","Didelphis PELA","Iguana PELA","Sphenodon PELA","Hyloplesion PELA","Pantylus PELA","Westlothiana PELA","Seymouria PELA","Ambystoma PELA","Salamandra PELA","Celtedens PELA","Eryops PELA","Balanerpeton PELA","Tulerpeton PELA","Ichthyostega PELA","Acanthostega PELA","Tiktaalik PELA","Panderichthys PELA","Mandageria PELA","Cabonnichthys PELA","Eusthenopteron PELA","Gogonasus PELA","Sterropteryon PELA","Sauripterus PELA","Neoceratodus PELA","Latimeria PELA","Polypterus PELA")
no_pec_networks<-which(networks %in% c("Westlothiana PECA","Ichthyostega PECA","Acanthostega PECA"))
no_pel_networks<-which(networks %in% c("Tiktaalik PELA","Mandageria PELA","Cabonnichthys PELA","Gogonasus PELA","Sauripterus PELA"))
networks<-networks[-c(no_pec_networks,no_pel_networks)] # delete entry for which there is no good fossil data
pec_index<-1:24  # taxa with pectoral appendages in data
pel_index<-25:46 # taxa with pelvic appendages in data
pec_pel_index<-c(1:46)[-which(networks %in% c("Westlothiana PELA","Ichthyostega PELA","Acanthostega PELA","Tiktaalik PECA","Mandageria PECA","Cabonnichthys PECA","Gogonasus PECA","Sauripterus PECA"))]
pec_subsample_index<-head(pec_pel_index,length(pec_pel_index)/2)
pel_subsample_index<-tail(pec_pel_index,length(pec_pel_index)/2)


# Functions
# Wilcox test to evaluate modules
community.significance.test <- function(graph, vids, ...) {
  subgraph <- induced_subgraph(graph, vids)
  in.degrees <- igraph::degree(subgraph)
  out.degrees <- igraph::degree(graph, vids) - in.degrees
  w.test <- wilcox.test(in.degrees, out.degrees, alternative="greater")
  return(w.test)
}
# Jackknife of modularity Q value
jackknife_Q <- function(graph, membership){
  Qi <- vector()
  for (j in 1:ecount(graph)){
    g <- delete_edges(graph, j)
    Qi[j] <- modularity(g, membership)
  }
  ss <- sum((Qi-mean(Qi))^2)
  n <- (ecount(graph)-1)/ecount(graph)
  Q.error <- sqrt(n*ss)
  return(Q.error)
}
# Heterogeneity of connections (H)
heterogeneity <- function(graph){
  deg <- igraph::degree(graph)
  res <- sd(deg, na.rm=TRUE)/mean(deg, na.rm=FALSE)
  return(res)
}
# Parcellation index (P)
parcellation_index <- function(membership){
  Nm <- vector()
  for (i in 1:max(membership)){
    Nm[i] <- length(which(membership==i))
  }
  res <- 1-sum((Nm/length(membership))^2)
  return(res)
}

#############################################################################################################


#############################################################################################################
# MAKE NETWORK MODELS
#############################################################################################################

# Load data
mat.list<-mapply(read.xlsx,file="extended_adjacency_matrices.xlsx",sheetIndex=1:length(networks),check.names=FALSE)

# Prepare data
mat.list<-lapply(mat.list,function(x){x["NA"]<-NULL;x})
for (i in 1:length(networks)){max.dim<-dim(mat.list[[i]])[1]; mat.list[[i]]<-mat.list[[i]][,1:max.dim]}

# Create igraph objects in a list
adj.list<-lapply(mat.list,data.matrix,rownames.force=FALSE)
graph.list<-lapply(adj.list,graph_from_adjacency_matrix,mode="undirected")
graph.list<-lapply(graph.list,simplify) # make sure there are no loops and multi-links
names(graph.list) <- networks

#############################################################################################################


#############################################################################################################
# COMMUNITY DETECTION (TO CALCULATE P LATER)
#############################################################################################################

# Get communities
communities<-list()
start_time<-Sys.time() # control it does not take too much
for(i in 1:length(networks)){communities[[i]]<-cluster_optimal(graph.list[[i]])}
end_time<-Sys.time()
print(end_time-start_time) # checks how long it takes

# Get modularity global results
modules<-matrix(NA,nrow=length(networks),ncol=3)
for(i in 1:length(networks)){
  modules[i,1]<-length(communities[[i]])  # number of modules found
  modules[i,2]<-modularity(communities[[i]])  # value of the optimization parameter Q
  modules[i,3]<-jackknife_Q(graph.list[[i]],membership(communities[[i]]))  # expected error of the value Q
}
# save modularity
modules<-data.frame(modules, row.names=networks)
colnames(modules)<-c("Number of Modules","Q value","Q expected error")
write.xlsx(modules,file="extended/STable. Results optimal-modularity algorithm on extended networks.xlsx",sheetName="Sheet1")

# Get modularity details for each network
list.modules<-list()
for(i in 1:length(networks)){
  graph<-graph.list[[i]]
  community<-communities[[i]]
  mod.tab<-matrix(NA,nrow=length(community),ncol=3)
  colnames(mod.tab)<-c("Module number", "p-value","Nodes grouped")
  for(j in 1:length(community)){
    mod.tab[j,1]<-paste(j)
    mod.tab[j,2]<-round(community.significance.test(graph,vids=(membership(community)==j))$p.value,digits=5)
    mod.tab[j,3]<-paste(V(graph)$name[membership(community)==j],collapse=", ")
  }
  list.modules[[i]]<-mod.tab
}
# save details of specific modules
names(list.modules)<-networks
for(i in 1:length(networks)){ # sometimes fails to write all in one rund and need manual push of i
  modules2save<-data.frame(list.modules[[i]])
  write.xlsx(modules2save,file="extended/STables. Modules identified on extended networks.xlsx",sheetName=paste(networks[i]),append=TRUE,row.names=FALSE)
}

#############################################################################################################

#############################################################################################################
# MEASURE NETWORK PARAMETERS
#############################################################################################################

# Prepare output
parameters<-matrix(NA,nrow=length(networks),ncol=8)
rownames(parameters)<-networks
colnames(parameters)<-parameter_names

# Measure parameters  
parameters[,1]<-mapply(vcount,graph.list)
parameters[,2]<-mapply(ecount,graph.list)
parameters[,3]<-mapply(edge_density,graph.list)
parameters[,4]<-mapply(transitivity,graph.list,type="average",isolates="zero")
parameters[,5]<-mapply(mean_distance,graph.list,directed=FALSE)
parameters[,6]<-mapply(heterogeneity,graph.list)
parameters[,7]<-mapply(assortativity_degree,graph.list,directed=FALSE)
for(i in 1:length(networks)){parameters[i,8]<-parcellation_index(membership(communities[[i]]))}
parameters<-data.frame(parameters,row.names=networks)

# Save table raw parameters
write.xlsx(parameters, file="extended/Table 1. Network parameters of pectoral and pelvic appendages models (extended).xlsx", sheetName="Sheet1", row.names=TRUE)

# Transform count variables N and K for further analysis
parameters[,1]<-sqrt(parameters[,1])
parameters[,2]<-sqrt(parameters[,2])

# Correlation plot
svg(filename=paste("extended/SFigure. Distribution and correlations of network parameters (extended).svg"),width=10,height=10)
pairs.panels(parameters,lm=TRUE,hist.col="skyblue1")
dev.off()

# Divide pectoral and pelvic data  
pectoral_parameters<-parameters[pec_index,] # pectoral complete sample
pectoral_subsample_parameters<-parameters[pec_subsample_index,] # pectoral subsample: only with pelvic correspondence
pelvic_parameters<-parameters[pel_index,] # pelvic complete sample
pelvic_subsample_parameters<-parameters[pel_subsample_index,] # pelvic subsample: only with pectoral correspondence

#############################################################################################################


#############################################################################################################
# MAKE NICE PLOTS OF NETWORKS (OPTIONAL)
#############################################################################################################

library(network)    # alternative network objects (used only for plotting)
library(intergraph) # convert between alternative network objects
library(sna)        # alternative network objects

# Nodes clored by modules
for(i in 1:length(networks)){
  ig<-graph.list[[i]]
  ig<-ig%>%set_vertex_attr("degree",value=igraph::degree(ig))
  membership.label<-paste(communities[[i]]$membership," (p = ",round(as.numeric(list.modules[[i]][,2]),3)[communities[[i]]$membership],")",sep="")
  ig<-ig%>%set_vertex_attr("membership",value=membership.label)
  if(fin_limb[i]=="fin"){new_layout<-layout_with_fr(ig)  # try to adjust to the best layout for each type of appendage
  }else{new_layout<-layout_with_kk(ig)}
  net<-asNetwork(ig)
  p<-ggnet2(net,mode=new_layout,label=FALSE,color="membership",color.legend="Module (p-value)",color.palette="Set1",size="degree") +
    guides(size=FALSE) +
    geom_text_repel(label=network::get.vertex.attribute(net,"vertex.names"))
  # Save
  svg(filename=paste("extended_network_plots/",networks[i],"extended network plot with colored modules.svg"),width=10,height=7)
  print(p)
  dev.off()
}

# Nodes equally colored
for(i in 1:length(networks)){
  ig<-graph.list[[i]]
  ig<-ig%>%set_vertex_attr("degree",value=igraph::degree(ig))
  if(fin_limb[i]=="fin"){new_layout<-layout_with_fr(ig) # try to adjust to the best layout for each type of appendage
  }else{new_layout<-layout_with_kk(ig)}
  net<-asNetwork(ig)
  p<-ggnet2(net,mode=new_layout,edge.size=0.5,label=FALSE,color="#a68a56",show.legend=FALSE,size="degree") +
    guides(size=FALSE) +
    geom_text_repel(label=network::get.vertex.attribute(net,"vertex.names"),segment.alpha=0,color="#48608c")
  # Save
  svg(filename=paste("extended_network_plots/",networks[i],"extended network plot with colored modules.svg"),width=10,height=7)
  print(p)
  dev.off()
}

#############################################################################################################


#############################################################################################################
# TREE BUILDING
#############################################################################################################

# Input tree topology
tree_topology<-read.tree(text="((((((((((((((((Mus,Didelphis),(Iguana,Sphenodon)),((Hyloplesion,Pantylus),Westlothiana)),Seymouria),((((Ambystoma,Salamandra),Celtedens),Balanerpeton),Eryops)),Tulerpeton),Ichthyostega),Acanthostega),Tiktaalik),Panderichthys),((Mandageria,Cabonnichthys),Eusthenopteron)),(Gogonasus,Sterropterygion)),Sauripterus),Neoceratodus),Latimeria),Polypterus);")

# First and last appearance dates (FAD, LAD)
FAD_LAD<-matrix(ncol=2,byrow=TRUE,data=
                  c(73,0, # Polypterus
                    22,0, # Latimeria
                    28.4,0, # Neoceratodus
                    361,358.9, # Sauripterus
                    361,358.9, # Sterropterygion
                    383.9,380, # Gogonasus
                    387.2,375, # Eusthenopteron
                    376.9,358.9, # Cabonnichthys
                    376.9,358.9, # Mandageria
                    387.2,380, # Panderichthys
                    383.9,376.1, # Tiktaalik
                    367.5,360.7, # Acanthostega
                    367.5,360.7, # Ichthyostega
                    358,354, # Tulerpeton
                    335,326.4, # Balanerpeton
                    297.2,272.5, # Eryops
                    167,100.5, # Celtedens
                    12,0, # Salamandra
                    42,0, # Ambystoma
                    298.5,272.5, # Seymouria
                    335,326.4, # Westlothiana
                    285.9,251.9, # Pantylus
                    308,298.9, # Hyloplesion
                    19,0, # Sphenodon
                    13,0, # Iguana
                    12,0, # Didelphis
                    10,0)) # Mus	
rownames(FAD_LAD)<-rev(tree_topology$tip.label)
colnames(FAD_LAD)<-c("FAD", "LAD")

# Set minimum dates for internal nodes (splits)
split_time<-rep(NA,tree_topology$Nnode)
split_time[28-27]<-419    # Actinopterygian-Sarcopterygian (Zhu et al. 2009)
split_time[29-27]<-416    # Actinistia-Rhipidistia (Swartz 2012)
split_time[30-27]<-408    # Dipnomorpha-Tetrapodomorpha (Benton et al. 2015)
split_time[39-27]<-330.4 # Batrachomorpha-Reptiliomorpha (Hedges & Kumar)
split_time[42-27]<-312.3 # Synapsida-Diapsida (Hedges & Kumar)
split_time[43-27]<-160   # Marsupialia-Placentalia (Luo et al. 2011)
split_time[44-27]<-238   # Rhynchocephalia-Squamata (Jones et al. 2013)
split_time[50-27]<-168   # Treptobranchia / Salamandroidea (Hedges & Kumar)

# Tree calibration using method 'equal' (Brusatte et al. 2008; Lloyd et al. 2012)
tree_calibrated<-timePaleoPhy(tree_topology,FAD_LAD,node.mins=split_time,type="equal",dateTreatment="firstLast",vartime=3,ntrees=1,add.term=T)

# Prepare trees
tree_pectoral<-drop.tip(phy=tree_calibrated,tip=c("Westlothiana","Ichthyostega","Acanthostega")) # remove taxa without pectoral appendages represented
tree_pelvic<-drop.tip(phy=tree_calibrated,tip=c("Sauripterus","Gogonasus","Cabonnichthys","Mandageria","Tiktaalik")) # remove taxa without pelvic appendages represented
tree_pectoral_pelvic<-drop.tip(phy=tree_calibrated,tip=c("Westlothiana","Ichthyostega","Acanthostega","Sauripterus","Gogonasus","Cabonnichthys","Mandageria","Tiktaalik")) # remove taxa without both appendages

# Save tree plot with the stratigraphical ranges included
svg(filename=paste("Figure 1B. Calibrated phylogeny.svg"),width=7,height=5)
geoscalePhylo(tree=tree_calibrated,ages=FAD_LAD,units=c("Period","Epoch"),boxes="Period",cex.age=0.5,cex.ts=0.45,cex.tip=0.5,quat.rm=T,x.lim=c(410,-20))
dev.off()

#############################################################################################################


#############################################################################################################
# SAVE NETWORK ANALYSIS WORKSPACE
#############################################################################################################

# Clean
rm(modules,list.modules,mod.tab,modules,end_time,start_time,graph,community,modules2save,mat.list,adj.list,i,j,split_time,ig,net,p,max.dim,start_time,end_time,graph,community,mod.tab,modules2save,new_layout,membership.label)

# Save
save.image("extended_networks_analysis_workspace.RData")

#############################################################################################################


#############################################################################################################
# ANALYSIS OF VARIANCE OF THE SAMPLE NETWORKS
#############################################################################################################

set.seed(73) # to get always same rotation + permanova

# Define grouping variables
pectoral_pelvic<-rep("pectoral",length(networks)); pectoral_pelvic[pel_index]<-"pelvic" # grouping variable pectoral vs pelvic
fin_limb<-rep("limb",length(networks)); fin_limb[c(14:24,41:46)]<-"fin" # grouping variable fin vs. limb
extinct_extant<-rep("extinct",length(networks)); extinct_extant[c(1,2,3,4,8,9,22,23,24,25,26,27,28,44,45,46)]<-"extant" # grouping variable extinct vs extant

# Compute PCA of all appendages
data<-parameters
pca_all<-prcomp(data,center=TRUE,scale.=TRUE) # centered in 0, scale=standarize variables because they have different units/ranges

# Save raw results
write.xlsx(data.frame(pca_all$x),file="extended/pca/STable. PCA scores for complete sample (extended).xlsx",sheetName="Sheet1",row.names=TRUE) # print(all.pca)
write.xlsx(data.frame(summary(pca_all)$importance),file="extended/PCA/STable. Variance distribution across PCs for complete sample (extended).xlsx",sheetName="Sheet1",row.names=TRUE) # summary(all.pca)

# Prepare plots PC1 vs PC2
p1<-ggbiplot(pca_all,obs.scale=1,var.scale=1,ellipse=FALSE,alpha=0) +
  geom_text_repel(label=strtrim(networks,3),size=3,segment.color="gray50") +
  scale_shape_discrete(name=NULL) +
  geom_point(aes(shape=pectoral_pelvic),show.legend=NA) +
  theme_classic() +
  theme(legend.direction='horizontal',legend.position='top') +
  coord_fixed(xlim=c(-4.5,7.5),ylim=c(-4.5,7.5))

# PERMANOVA fins vs limbs
permapca<-adonis(pca_all$x~fin_limb,method='eu',permutations=10000) # same that using scale(parameters) ~ groups
test_text<-paste("F(",permapca$aov.tab$Df[1],",",permapca$aov.tab$Df[2],")"," = ",round(permapca$aov.tab$F.Model[1],3),", p = ",signif(permapca$aov.tab$Pr[1],4),sep="")
p2<-ggbiplot(pca_all,obs.scale=1,var.scale=1,ellipse=TRUE,ellipse.prob=0.68,groups=fin_limb,alpha=0) +
  scale_color_brewer(name='',type="div",palette="Set1") +
  theme_classic() +
  theme(legend.direction='horizontal',legend.position='top') +
  geom_point(aes(shape=factor(pectoral_pelvic),colour=factor(fin_limb)),show.legend=FALSE) +
  annotate("text",x=-2,y=5,label=test_text,hjust=0,size=3) +
  coord_fixed(xlim=c(-4.5,7.5),ylim=c(-4.5,7.5))

# PERMANOVA pectoral vs pelvic
permapca<-adonis(pca_all$x~pectoral_pelvic,method='eu',permutations=10000) # same that using scale(parameters) ~ groups
test_text<-paste("F(",permapca$aov.tab$Df[1],",",permapca$aov.tab$Df[2],")"," = ",round(permapca$aov.tab$F.Model[1],3),", p = ",signif(permapca$aov.tab$Pr[1],4),sep="")
p3<-ggbiplot(pca_all,obs.scale=1,var.scale=1,ellipse=TRUE,ellipse.prob=0.68,groups=pectoral_pelvic,alpha=0) +
  scale_color_brewer(name='',type="seq",palette="Set2",direction = -1) +
  theme_classic() +
  theme(legend.direction='horizontal',legend.position='top') +
  geom_point(aes(shape=factor(pectoral_pelvic),colour=factor(pectoral_pelvic)),show.legend=FALSE) +
  annotate("text",x=-2,y=5,label=test_text,hjust=0,size=3) +
  coord_fixed(xlim=c(-4.5,7.5),ylim=c(-4.5,7.5))

# PERMANOVA extinct vs extant
permapca<-adonis(pca_all$x~extinct_extant,method='eu',permutations=10000) # same that using scale(parameters) ~ groups
test_text<-paste("F(",permapca$aov.tab$Df[1],",",permapca$aov.tab$Df[2],")"," = ",round(permapca$aov.tab$F.Model[1],3),", p = ",signif(permapca$aov.tab$Pr[1],4),sep="")
p4<-ggbiplot(pca_all,obs.scale=1,var.scale=1,ellipse=TRUE,ellipse.prob=0.68,groups=extinct_extant,alpha=0) +
  scale_color_brewer(name='',type="div",palette="Dark2") +
  theme_classic() +
  theme(legend.direction='horizontal',legend.position='top') +
  geom_point(aes(shape=factor(pectoral_pelvic),colour=factor(extinct_extant)),show.legend=FALSE) +
  annotate("text",x=-2,y=5,label=test_text,hjust=0,size=3) +
  coord_fixed(xlim=c(-4.5,7.5),ylim=c(-4.5,7.5))

# Save plot (main Figure 2)
svg(filename=paste("extended/pca/Figure. PCA of appendages topology (extended).svg"),width=7,height=7)
grid.arrange(arrangeGrob(p1,p2,ncol=2), # first row, 2 columns
             arrangeGrob(p3,p4,ncol=2), # second row, 2 columns
             nrow=2)                    # number of rows
dev.off()

# Check how much variation does each species account for
scores<-pca_all$x
explained_variation<-apply(scores,1,sd)^2/sum(apply(scores,1,sd)^2)
explained_variation<-as.data.frame(explained_variation,row.names=names(explained_variation))
write.xlsx(explained_variation,file="extended/pca/STable. Explained variation of each network in PCA (extended).xlsx",sheetName="Sheet1",row.names=TRUE)

#############################################################################################################


#############################################################################################################
# EVOLUTIONARY ESTIMATION + MODEL FITTING
#############################################################################################################

##
## Pectoral complete sample
##
con<-file("extended/evo/pectoral complete PC12.log")
sink(con, append=TRUE)
set.seed(73)

# Load data and tree
tree<-tree_pectoral
data<-pectoral_parameters

rownames(data)<-tree$tip.label
pca_data<-phyl.pca(tree,data,method = "BM")
dat<-pca_data$S[,1:2]; rownames(dat)<-tree$tip.label
#pca_data<-prcomp(data,center=TRUE,scale.=TRUE)
#dat<-pca_data$x[,1:8]; rownames(dat)<-tree$tip.label
#dat<-pectoral_parameters; rownames(dat)<-tree$tip.label


# SURFACE (Evolutionary estimation)
# prepare data and tree
tree<-treedata(tree,dat,sort=T,warnings=T)$phy #plot(tree); nodelabels()
dat<-as.data.frame(treedata(tree,dat,sort=TRUE)$data) #summary(dat)
tr<-nameNodes(tree)
olist<-convertTreeData(tr,dat)
otree<-olist[[1]]; odata<-olist[[2]]
# forward
fwd<-surfaceForward(otree,odata,aic_threshold=-2,exclude=0,verbose=FALSE,plotaic=FALSE)
k<-length(fwd)
fsum<-surfaceSummary(fwd)
names(fsum)
fsum$aics
# backward
bwd<-surfaceBackward(otree,odata,starting_model=fwd[[k]],aic_threshold=0,only_best=FALSE,verbose=FALSE,plotaic=FALSE)
bsum<-surfaceSummary(bwd)
kk<-length(bwd)
# output
bsum$alpha
bsum$sigma_squared
bsum$theta
bsum$n_regimes
surfaceTreePlot(tr,bwd[[kk]],labelshifts=F,cex=0.5,edge.width=2,convcol=F,col=c("green","black","blue","cyan","orange","red"))
# signal
print("SIGNAL-TO-NOISE RATION (>1 GOOD)")
SNR_pectoral_complete_sample<-(sqrt(2*branching.times(tree)[[1]])*bsum$alpha*min(abs(bsum$theta)))/sqrt(bsum$sigma_squared)  
SNR_pectoral_complete_sample
surface_pectoral_complete_sample<-bwd

# Model fitting
dat<-as.matrix(dat)
# grouping (following SURFACE results)
Node_limbs<-findMRCA(tree,c("Mus","Latimeria"))
# mapping estimated regimes
treemap<-paintSubTree(tree,node=Node_limbs,state=2,stem=TRUE)
# fitting models of evolution
Fit_BM1<-mvMORPH::mvBM(treemap,data=dat,error=NULL,model="BM1",control=list(maxit=100000))
Fit_BMM<-mvMORPH::mvBM(treemap,data=dat,error=NULL,model="BMM",control=list(maxit=100000))
Fit_OU1<-mvOU(treemap,data=dat,error=NULL,model="OU1",param=list(sigma="constraint",alpha="constraint"),control=list(maxit=100000)) # fixed rate, strength, mean optimal
Fit_OUMv<-mvOU(treemap,data=dat,error=NULL,model="OUM",param=list(alpha="constraint"),control=list(maxit=100000)) # fixed strength (changing rate and mean)
Fit_OUM<-mvOU(treemap,data=dat,error=NULL,model="OUM",param=list(sigma="constraint",alpha="constraint"),control=list(maxit=100000)) # fixed rate & strength mean (changing mean)
# comparing models
weights<-c(Fit_BM1$AICc,Fit_BMM$AICc,Fit_OU1$AICc,Fit_OUMv$AICc,Fit_OUM$AICc)
names(weights)<-c("BM 1-rate","BM multi-rate","OU 1-regime","OUM multi-sigma&mean","OUM multi-mean")
print("BEST MODEL FIT")
geiger::aicw(weights)

# Save output plots
svg("extended/evo/SFigure. SURFACE pectoral complete PC12 tree (extended).svg")
tree_colors<-setNames(c("black","green","blue"),1:3) 
plot(treemap,colors=tree_colors)
dev.off()

svg(filename=paste("extended/evo/SFigure. SURFACE pectoral complete PC12 data (extended).svg"),width=7,height=7)
dat<-as.data.frame(dat,rownames(dat))
samp.names<-tree$tip.label
samp.data<-data.frame(samp=factor(samp.names,levels=samp.names,ordered=TRUE),value=dat$PC1)
p1<-ggplot(samp.data,aes(x=samp,y=value)) +
  geom_bar(stat="identity", position = "identity") +
  labs(x="",y="PC1") +
  theme(axis.ticks.y=element_blank(),axis.text.y=element_blank()) +
  scale_y_continuous(limits = c(-max(abs(samp.data$value)), max(abs(samp.data$value)))) +
  coord_flip()
samp.data<-data.frame(samp=factor(samp.names,levels=samp.names,ordered=TRUE),value=dat$PC2)
p2<-ggplot(samp.data,aes(x=samp,y=value)) +
  geom_bar(stat="identity", position = "identity") +
  labs(x="",y="PC2") +
  theme(axis.ticks.y=element_blank(),axis.text.y=element_blank()) +
  scale_y_continuous(limits = c(-max(abs(samp.data$value)), max(abs(samp.data$value)))) +
  coord_flip()
grid.arrange(arrangeGrob(p1,p2,ncol=2),nrow=1)
dev.off()

# Test the Ho that these groups are different phyloMANOVA
outree<-geiger::rescale(tree,model='OU',alpha=0.5)
lentree<-length(tree$tip.label)
A<-getDescendants(tree,Node_limbs)[getDescendants(tree,Node_limbs)<lentree]
grp<-rep(1,lentree)
grp[A]<-2
names(grp)<-tree$tip.label; grp<-as.factor(grp)
print("pMANOVA WITH OU-TREE")
aov.phylo(dat~grp,outree,nsim=10000,test="Wilks")
print("pMANOVA WITH BM-TREE")
aov.phylo(dat~grp,tree,nsim=10000,test="Wilks")
# test the fins-vs-limb groups
lentree<-length(tree$tip.label)
Node_limbs<-findMRCA(tree,c("Mus","Tulerpeton"))
A<-getDescendants(tree,Node_limbs)[getDescendants(tree,Node_limbs)<lentree]
grp<-rep(1,lentree)
grp[A]<-2
names(grp)<-tree$tip.label; grp<-as.factor(grp)
print("pMANOVA WITH BM-TREE FIN-LIMB")
aov.phylo(dat~grp,tree,nsim=10000,test="Wilks")

sink() # closes the connection

##
## Pelvic complete sample
##
con <- file("extended/evo/pelvic complete PC12.log")
sink(con, append=TRUE)
set.seed(73)

# Load data and tree
tree<-tree_pelvic
data<-pelvic_parameters
rownames(data)<-tree$tip.label
pca_data<-phyl.pca(tree,data,method = "BM")
dat<-pca_data$S[,1:2]; rownames(dat)<-tree$tip.label
#pca_data<-prcomp(data,center=TRUE,scale.=TRUE)
#dat<-pca_data$x[,1:8]; rownames(dat)<-tree$tip.label
#dat<-pectoral_parameters; rownames(dat)<-tree$tip.label


# SURFACE (Evolutionary estimation)
# prepare data and tree
tree<-treedata(tree,dat,sort=T,warnings=T)$phy
dat<-as.data.frame(treedata(tree,dat,sort=TRUE)$data)
tr<-nameNodes(tree)
olist<-convertTreeData(tr,dat)
otree<-olist[[1]]; odata<-olist[[2]]
# forward
fwd<-surfaceForward(otree,odata,aic_threshold=-2,exclude=0,verbose=FALSE,plotaic=FALSE)
k<-length(fwd)
fsum<-surfaceSummary(fwd)
names(fsum)
fsum$aics
# backward
bwd<-surfaceBackward(otree,odata,starting_model=fwd[[k]],aic_threshold=0,only_best=FALSE,verbose=FALSE,plotaic=FALSE)
bsum<-surfaceSummary(bwd)
kk<-length(bwd)
# output
bsum$alpha
bsum$sigma_squared
bsum$theta
bsum$n_regimes
surfaceTreePlot(tr,bwd[[kk]],labelshifts=F,cex=0.5,edge.width=2,convcol=F,col=c("black","green","blue","cyan","orange","red"))
# signal
print("SIGNAL-TO-NOISE RATION (>1 GOOD)")
SNR_pelvic_complete_sample<-(sqrt(2*branching.times(tree)[[1]])*bsum$alpha*min(abs(bsum$theta)))/sqrt(bsum$sigma_squared)  
SNR_pelvic_complete_sample
surface_pelvic_complete_sample<-bwd

dat<-as.matrix(dat)
# grouping (following SURFACE results)
Node_limbs<-findMRCA(tree,c("Mus","Latimeria"))
# mapping estimated regimes
treemap<-paintSubTree(tree,node=Node_limbs,state=2,stem=TRUE)
# fitting models of evolution
Fit_BM1<-mvMORPH::mvBM(treemap,data=dat,error=NULL,model="BM1",control=list(maxit=100000))
Fit_BMM<-mvMORPH::mvBM(treemap,data=dat,error=NULL,model="BMM",control=list(maxit=100000))
Fit_OU1<-mvOU(treemap,data=dat,error=NULL,model="OU1",param=list(sigma="constraint",alpha="constraint"),control=list(maxit=100000)) # fixed rate, strength, mean optimal
Fit_OUMv<-mvOU(treemap,data=dat,error=NULL,model="OUM",param=list(alpha="constraint"),control=list(maxit=100000)) # fixed strength (changing rate and mean)
Fit_OUM<-mvOU(treemap,data=dat,error=NULL,model="OUM",param=list(sigma="constraint",alpha="constraint"),control=list(maxit=100000)) # fixed rate & strength mean (changing mean)
# comparing models
weights<-c(Fit_BM1$AICc,Fit_BMM$AICc,Fit_OU1$AICc,Fit_OUMv$AICc,Fit_OUM$AICc)
names(weights)<-c("BM 1-rate","BM multi-rate","OU 1-regime","OUM multi-sigma&mean","OUM multi-mean")
print("BEST MODEL FIT")
geiger::aicw(weights)

# Saving output plots
svg("extended/evo/SFigure. SURFACE pelvic complete PC12 tree (extended).svg")
tree_colors<-setNames(c("black","green","cyan","blue"),1:4) 
plot(treemap,colors=tree_colors)
dev.off()

svg(filename=paste("extended/evo/SFigure. SURFACE pelvic complete PC12 data (extended).svg"),width=7,height=7)
dat<-as.data.frame(dat,rownames(dat))
samp.names<-tree$tip.label
samp.data<-data.frame(samp=factor(samp.names,levels=samp.names,ordered=TRUE),value=dat$PC1)
p1<-ggplot(samp.data,aes(x=samp,y=value)) +
  geom_bar(stat="identity", position = "identity") +
  labs(x="",y="PC1") +
  theme(axis.ticks.y=element_blank(),axis.text.y=element_blank()) +
  scale_y_continuous(limits = c(-max(abs(samp.data$value)), max(abs(samp.data$value)))) +
  coord_flip()
samp.data<-data.frame(samp=factor(samp.names,levels=samp.names,ordered=TRUE),value=dat$PC2)
p2<-ggplot(samp.data,aes(x=samp,y=value)) +
  geom_bar(stat="identity", position = "identity") +
  labs(x="",y="PC2") +
  theme(axis.ticks.y=element_blank(),axis.text.y=element_blank()) +
  scale_y_continuous(limits = c(-max(abs(samp.data$value)), max(abs(samp.data$value)))) +
  coord_flip()
grid.arrange(arrangeGrob(p1,p2,ncol=2),nrow=1)
dev.off()

# Test the Ho that these groups are different phyloMANOVA
outree<-geiger::rescale(tree,model='OU',alpha=0.5)
lentree<-length(tree$tip.label)
A<-getDescendants(tree,Node_limbs)[getDescendants(tree,Node_limbs)<lentree]
grp<-rep(1,lentree)
grp[A]<-2
names(grp)<-tree$tip.label; grp<-as.factor(grp)
print("pMANOVA WITH OU-TREE")
aov.phylo(dat~grp,outree,nsim=10000,test="Wilks")
print("pMANOVA WITH BM-TREE")
aov.phylo(dat~grp,tree,nsim=10000,test="Wilks")
# test the fins-vs-limb groups
lentree<-length(tree$tip.label)
Node_limbs<-findMRCA(tree,c("Mus","Acanthostega"))
A<-getDescendants(tree,Node_limbs)[getDescendants(tree,Node_limbs)<lentree]
grp<-rep(1,lentree)
grp[A]<-2
names(grp)<-tree$tip.label; grp<-as.factor(grp)
print("pMANOVA WITH BM-TREE FIN-LIMB")
aov.phylo(dat~grp,tree,nsim=10000,test="Wilks")

sink() # closes the connection

##
## Pectoral subsample
##
con <- file("extended/evo/pectoral subsample PC12.log")
sink(con, append=TRUE)
set.seed(73)

# load data and tree
tree<-tree_pectoral_pelvic
data<-pectoral_subsample_parameters
rownames(data)<-tree$tip.label
pca_data<-phyl.pca(tree,data,method = "BM")
dat<-pca_data$S[,1:2]; rownames(dat)<-tree$tip.label
#pca_data<-prcomp(data,center=TRUE,scale.=TRUE)
#dat<-pca_data$x[,1:8]; rownames(dat)<-tree$tip.label
#dat<-pectoral_parameters; rownames(dat)<-tree$tip.label

# SURFACE (Evolutionary estimation)
# prepare data and tree
tree<-treedata(tree,dat,sort=T,warnings=T)$phy
dat<-as.data.frame(treedata(tree,dat,sort=TRUE)$data)
tr<-nameNodes(tree)
olist<-convertTreeData(tr,dat)
otree<-olist[[1]]; odata<-olist[[2]]
# forward
fwd<-surfaceForward(otree,odata,aic_threshold=-2,exclude=0,verbose=FALSE,plotaic=FALSE)
k<-length(fwd)
fsum<-surfaceSummary(fwd)
names(fsum)
fsum$aics
# backward
bwd<-surfaceBackward(otree,odata,starting_model=fwd[[k]],aic_threshold=0,only_best=FALSE,verbose=FALSE,plotaic=FALSE)
bsum<-surfaceSummary(bwd)
kk<-length(bwd)
# output
bsum$alpha
bsum$sigma_squared
bsum$theta
bsum$n_regimes
surfaceTreePlot(tr,bwd[[kk]],labelshifts=F,cex=0.5,edge.width=2,convcol=F,col=c("black","green","blue","cyan","orange","red"))
# signal
print("SIGNAL-TO-NOISE RATION (>1 GOOD)")
SNR_pectoral_subsample<-(sqrt(2*branching.times(tree)[[1]])*bsum$alpha*min(abs(bsum$theta)))/sqrt(bsum$sigma_squared)  
SNR_pectoral_subsample
surface_pectoral_subsample<-bwd

# Model fitting
dat<-as.matrix(dat)
# grouping (following SURFACE results)
Node_limbs<-findMRCA(tree,c("Mus","Latimeria"))
# mapping estimated regimes
treemap<-paintSubTree(tree,node=Node_limbs,state=2,stem=TRUE)
# fitting models of evolution
Fit_BM1<-mvMORPH::mvBM(treemap,data=dat,error=NULL,model="BM1",control=list(maxit=100000))  #Note that you can include a standard error for within-species variation 
Fit_BMM<-mvMORPH::mvBM(treemap,data=dat,error=NULL,model="BMM",control=list(maxit=100000))
Fit_OU1<-mvOU(treemap,data=dat,error=NULL,model="OU1",param=list(sigma="constraint",alpha="constraint"),control=list(maxit=100000)) # fixed rate, strength, mean optimal
Fit_OUMv<-mvOU(treemap,data=dat,error=NULL,model="OUM",param=list(alpha="constraint"),control=list(maxit=100000)) # fixed strength (changing rate and mean)
Fit_OUM<-mvOU(treemap,data=dat,error=NULL,model="OUM",param=list(sigma="constraint",alpha="constraint"),control=list(maxit=100000)) # fixed rate & strength mean (changing mean)
# comparing models
weights<-c(Fit_BM1$AICc,Fit_BMM$AICc,Fit_OU1$AICc,Fit_OUMv$AICc,Fit_OUM$AICc)
names(weights)<-c("BM 1-rate","BM multi-rate","OU 1-regime","OUM multi-sigma&mean","OUM multi-mean")
print("BEST MODEL FIT")
geiger::aicw(weights)

# Saving output plots
svg("extended/evo/SFigure. SURFACE pectoral subsample PC12 tree (extended).svg")
tree_colors<-setNames(c("green","black","blue"),1:3) 
plot(treemap,colors=tree_colors)
dev.off()

svg(filename=paste("extended/evo/SFigure. SURFACE pectoral subsample PC12 data (extended).svg"),width=7,height=7)
dat<-as.data.frame(dat,rownames(dat))
samp.names<-tree$tip.label
samp.data<-data.frame(samp=factor(samp.names,levels=samp.names,ordered=TRUE),value=dat$PC1)
p1<-ggplot(samp.data,aes(x=samp,y=value)) +
  geom_bar(stat="identity", position = "identity") +
  labs(x="",y="PC1") +
  theme(axis.ticks.y=element_blank(),axis.text.y=element_blank()) +
  scale_y_continuous(limits = c(-max(abs(samp.data$value)), max(abs(samp.data$value)))) +
  coord_flip()
samp.data<-data.frame(samp=factor(samp.names,levels=samp.names,ordered=TRUE),value=dat$PC2)
p2<-ggplot(samp.data,aes(x=samp,y=value)) +
  geom_bar(stat="identity", position = "identity") +
  labs(x="",y="PC2") +
  theme(axis.ticks.y=element_blank(),axis.text.y=element_blank()) +
  scale_y_continuous(limits = c(-max(abs(samp.data$value)), max(abs(samp.data$value)))) +
  coord_flip()
grid.arrange(arrangeGrob(p1,p2,ncol=2),nrow=1)
dev.off()

# Test the Ho that these groups are different phyloMANOVA
outree<-geiger::rescale(tree,model='OU',alpha=0.5)
lentree<-length(tree$tip.label)
A<-getDescendants(tree,Node_limbs)[getDescendants(tree,Node_limbs)<lentree]
grp<-rep(1,lentree)
grp[A]<-2
names(grp)<-tree$tip.label; grp<-as.factor(grp)
print("pMANOVA WITH OU-TREE")
aov.phylo(dat~grp,outree,nsim=10000,test="Wilks")
print("pMANOVA WITH BM-TREE")
aov.phylo(dat~grp,tree,nsim=10000,test="Wilks")
# Test the fins-vs-limb groups
Node_limbs<-findMRCA(tree,c("Mus","Tulerpeton"))
lentree<-length(tree$tip.label)
A<-getDescendants(tree,Node_limbs)[getDescendants(tree,Node_limbs)<lentree]
grp<-rep(1,lentree)
grp[A]<-2
names(grp)<-tree$tip.label; grp<-as.factor(grp)
print("pMANOVA WITH BM-TREE FIN-LIMB")
aov.phylo(dat~grp,tree,nsim=10000,test="Wilks")

sink() # closes the connection

##
## Pelvic subsample
##
con <- file("extended/evo/pelvic subsample PC12.log")
sink(con, append=TRUE)
set.seed(73)

# load data and tree
tree<-tree_pectoral_pelvic
data<-pelvic_subsample_parameters
rownames(data)<-tree$tip.label
pca_data<-phyl.pca(tree,data,method = "BM")
dat<-pca_data$S[,1:2]; rownames(dat)<-tree$tip.label
#pca_data<-prcomp(data,center=TRUE,scale.=TRUE)
#dat<-pca_data$x[,1:8]; rownames(dat)<-tree$tip.label
#dat<-pectoral_parameters; rownames(dat)<-tree$tip.label


# SURFACE (Evolutionary estimation)
# prepare data and tree
tree<-treedata(tree,dat,sort=T,warnings=T)$phy
dat<-as.data.frame(treedata(tree,dat,sort=TRUE)$data)
tr<-nameNodes(tree)
olist<-convertTreeData(tr,dat)
otree<-olist[[1]]; odata<-olist[[2]]
# forward
fwd<-surfaceForward(otree,odata,aic_threshold=-2,exclude=0,verbose=FALSE,plotaic=FALSE)
k<-length(fwd)
fsum<-surfaceSummary(fwd)
names(fsum)
fsum$aics
# backward
bwd<-surfaceBackward(otree,odata,starting_model=fwd[[k]],aic_threshold=0,only_best=FALSE,verbose=FALSE,plotaic=FALSE)
bsum<-surfaceSummary(bwd)
kk<-length(bwd)
# output
bsum$alpha
bsum$sigma_squared
bsum$theta
bsum$n_regimes
surfaceTreePlot(tr,bwd[[kk]],labelshifts=F,cex=0.5,edge.width=2,convcol=F,col=c("black","green","blue","cyan","orange","red"))
# signal
print("SIGNAL-TO-NOISE RATION (>1 GOOD)")
SNR_pelvic_subsample<-(sqrt(2*branching.times(tree)[[1]])*bsum$alpha*min(abs(bsum$theta)))/sqrt(bsum$sigma_squared)  
SNR_pelvic_subsample
surface_pelvic_subsample<-bwd

# Model fitting
dat<-as.matrix(dat)
# grouping (following SURFACE results)
Node_limbs<-findMRCA(tree,c("Mus","Latimeria"))
# mapping estimated regimes
treemap<-paintSubTree(tree,node=Node_limbs,state=2,stem=TRUE)
# fitting models of evolution
Fit_BM1<-mvMORPH::mvBM(treemap,data=dat,error=NULL,model="BM1",control=list(maxit=100000))
Fit_BMM<-mvMORPH::mvBM(treemap,data=dat,error=NULL,model="BMM",control=list(maxit=100000))
Fit_OU1<-mvOU(treemap,data=dat,error=NULL,model="OU1",param=list(sigma="constraint",alpha="constraint"),control=list(maxit=100000)) # fixed rate, strength, mean optimal
Fit_OUMv<-mvOU(treemap,data=dat,error=NULL,model="OUM",param=list(alpha="constraint"),control=list(maxit=100000)) # fixed strength (changing rate and mean)
Fit_OUM<-mvOU(treemap,data=dat,error=NULL,model="OUM",param=list(sigma="constraint",alpha="constraint"),control=list(maxit=100000)) # fixed rate & strength mean (changing mean)
# comparing models
weights<-c(Fit_BM1$AICc,Fit_BMM$AICc,Fit_OU1$AICc,Fit_OUMv$AICc,Fit_OUM$AICc)
names(weights)<-c("BM 1-rate","BM multi-rate","OU 1-regime","OUM multi-sigma&mean","OUM multi-mean")
print("BEST MODEL FIT")
geiger::aicw(weights)


# Saving output plots
svg("extended/evo/SFigure. SURFACE pelvic subsample PC12 tree (extended).svg")
tree_colors<-setNames(c("black","green","cyan","blue"),1:4) 
plot(treemap,colors=tree_colors)
dev.off()

svg(filename=paste("extended/evo/SFigure. SURFACE pelvic subsample PC12 data (extended).svg"),width=7,height=7)
dat<-as.data.frame(dat,rownames(dat))
samp.names<-tree$tip.label
samp.data<-data.frame(samp=factor(samp.names,levels=samp.names,ordered=TRUE),value=dat$PC1)
p1<-ggplot(samp.data,aes(x=samp,y=value)) +
  geom_bar(stat="identity", position = "identity") +
  labs(x="",y="PC1") +
  theme(axis.ticks.y=element_blank(),axis.text.y=element_blank()) +
  scale_y_continuous(limits = c(-max(abs(samp.data$value)), max(abs(samp.data$value)))) +
  coord_flip()
samp.data<-data.frame(samp=factor(samp.names,levels=samp.names,ordered=TRUE),value=dat$PC2)
p2<-ggplot(samp.data,aes(x=samp,y=value)) +
  geom_bar(stat="identity", position = "identity") +
  labs(x="",y="PC2") +
  theme(axis.ticks.y=element_blank(),axis.text.y=element_blank()) +
  scale_y_continuous(limits = c(-max(abs(samp.data$value)), max(abs(samp.data$value)))) +
  coord_flip()
grid.arrange(arrangeGrob(p1,p2,ncol=2),nrow=1)
dev.off()

outree<-geiger::rescale(tree,model='OU',alpha=0.5)
lentree<-length(tree$tip.label)
A<-getDescendants(tree,Node_limbs)[getDescendants(tree,Node_limbs)<lentree]
grp<-rep(1,lentree)
grp[A]<-2
names(grp)<-tree$tip.label; grp<-as.factor(grp)
print("pMANOVA WITH OU-TREE")
aov.phylo(dat~grp,outree,nsim=10000,test="Wilks")
print("pMANOVA WITH BM-TREE")
aov.phylo(dat~grp,tree,nsim=10000,test="Wilks")
# Test the fins-vs-limb groups
Node_limbs<-findMRCA(tree,c("Mus","Tulerpeton"))
lentree<-length(tree$tip.label)
A<-getDescendants(tree,Node_limbs)[getDescendants(tree,Node_limbs)<lentree]
grp<-rep(1,lentree)
grp[A]<-2
names(grp)<-tree$tip.label; grp<-as.factor(grp)
print("pMANOVA WITH BM-TREE FIN-LIMB")
aov.phylo(dat~grp,tree,nsim=10000,test="Wilks")

sink() # closes the connection

#############################################################################################################


#############################################################################################################
# DISPARITY TRHOUGH TIME
#############################################################################################################

##
## Pectoral complete sample
##
set.seed(73)

# Prepare data
data<-pectoral_parameters
tree<-tree_pectoral
rownames(data)<-tree$tip.label
pca_data<-phyl.pca(tree,data,method = "BM")
dat<-pca_data$S; rownames(dat)<-tree$tip.label
tree<-treedata(tree,dat,sort=T,warnings=T)$phy
dat<-treedata(tree,dat,sort=T,warnings=T)$data

# DTT
disp<-dtt(tree,dat,index="avg.sq",nsim=10000,CI=0.95,plot=FALSE,calculateMDIp=F)
dtt_ma_time<-tree$root.time-(tree$root.time*disp$times)
dtt_sim_mean<-apply(disp$sim,1,mean)
dtt_sim_botCI<-dtt_sim_topCI<-vector()
for (i in 1:length(dtt_sim_mean)){
  dtt_sim_botCI[i]<-as.numeric(quantile(disp$sim[i,],0.025))
  dtt_sim_topCI[i]<-as.numeric(quantile(disp$sim[i,],0.975))
}
# output
output_dtt<-data.frame(cbind(dtt_ma_time,disp$dtt,dtt_sim_mean,dtt_sim_botCI,dtt_sim_topCI))
colnames(output_dtt)<-c("time","dtt","sim_mean","botci","topci")
test_text<-paste("Rand Inference",
                 "\n sim = 10,000",
                 "\n MDI =",round(disp$MDI,3),
                 "\n p =",formatC(getMDIp(disp)))
# visualize
p<-ggplot(output_dtt,aes(x=time,y=dtt)) +
  geom_ribbon(aes(ymin=botci,ymax=topci),fill="grey90") +
  geom_line(size=1.25) +
  geom_line(aes(y=sim_mean),linetype="dotted",size=1) +
  theme_bw() + theme(panel.border=element_blank(),panel.grid.major=element_blank(),panel.grid.minor=element_blank(),axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  scale_x_reverse() +
  xlab("Time (Mya)") + ylab("Pectoral DTT (complete sample)") +
  geom_vline(xintercept=419,color="red",linetype="dashed") + # First sarcopterigyans Benton M.J. and Donoghue P.C.J. 2006
  annotate("text",x=417,y=2.5,label="Sarcopterygii",hjust=0,size=4) +
  geom_vline(xintercept=397,color="green",linetype="dashed") + # Zachelmie tracks (Niedzwiedzki et al. 2010)
  annotate("text",x=395,y=2.25,label="Zachelmie tracks",hjust=0,size=4) +
  geom_vline(xintercept=355,color="blue",linetype="dashed") + # Crown group tetrapoda (Clack et al 2016)
  annotate("text",x=353,y=2,label="Tetrapoda",hjust=0,size=4) +
  geom_vline(xintercept=312.3,color="red",linetype="dashed") + # First amniotes Benton M.J. and Donoghue P.C.J. 2006
  annotate("text",x=310,y=1.75,label="Amniota",hjust=0,size=4) +
  annotate("text",x=250,y=1.75,label=test_text,hjust=0,size=3.5) +
  scale_y_continuous(limits=c(0,max(output_dtt$topci)))
dtt_pectoral_complete<-p

##
## Pectoral subsample
##
set.seed(73)

# Prepare data
data<-pectoral_subsample_parameters
tree<-tree_pectoral_pelvic
rownames(data)<-tree$tip.label
pca_data<-phyl.pca(tree,data,method = "BM")
dat<-pca_data$S; rownames(dat)<-tree$tip.label
tree<-treedata(tree,dat,sort=T,warnings=T)$phy
dat<-treedata(tree,dat,sort=T,warnings=T)$data

# DTT
disp<-dtt(tree,dat,index="avg.sq",nsim=10000,CI=0.95,plot=FALSE,calculateMDIp=F)
dtt_ma_time<-tree$root.time-(tree$root.time*disp$times)
dtt_sim_mean<-apply(disp$sim,1,mean)
dtt_sim_botCI<-dtt_sim_topCI<-vector()
for (i in 1:length(dtt_sim_mean)){
  dtt_sim_botCI[i]<-as.numeric(quantile(disp$sim[i,],0.025))
  dtt_sim_topCI[i]<-as.numeric(quantile(disp$sim[i,],0.975))
}
# output
output_dtt<-data.frame(cbind(dtt_ma_time,disp$dtt,dtt_sim_mean,dtt_sim_botCI,dtt_sim_topCI))
colnames(output_dtt)<-c("time","dtt","sim_mean","botci","topci")
test_text<-paste("Rand Inference",
                 "\n sim = 10,000",
                 "\n MDI =",round(disp$MDI,3),
                 "\n p =",formatC(getMDIp(disp)))
# visualize
p<-ggplot(output_dtt,aes(x=time,y=dtt)) +
  geom_ribbon(aes(ymin=botci,ymax=topci),fill="grey90") +
  geom_line(size=1.25) +
  geom_line(aes(y=sim_mean),linetype="dotted",size=1) +
  theme_bw() + theme(panel.border=element_blank(),panel.grid.major=element_blank(),panel.grid.minor=element_blank(),axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  scale_x_reverse() +
  xlab("Time (Mya)") + ylab("Pectoral DTT (subsample)") +
  geom_vline(xintercept=419,color="red",linetype="dashed") + # First sarcopterigyans Benton M.J. and Donoghue P.C.J. 2006
  annotate("text",x=417,y=2.5,label="Sarcopterygii",hjust=0,size=4) +
  geom_vline(xintercept=397,color="green",linetype="dashed") + # Zachelmie tracks (Niedzwiedzki et al. 2010)
  annotate("text",x=395,y=2.25,label="Zachelmie tracks",hjust=0,size=4) +
  geom_vline(xintercept=355,color="blue",linetype="dashed") + # Crown group tetrapoda (Clack et al 2016)
  annotate("text",x=353,y=2,label="Tetrapoda",hjust=0,size=4) +
  geom_vline(xintercept=312.3,color="red",linetype="dashed") + # First amniotes Benton M.J. and Donoghue P.C.J. 2006
  annotate("text",x=310,y=1.75,label="Amniota",hjust=0,size=4) +
  annotate("text",x=250,y=1.75,label=test_text,hjust=0,size=3.5) +
  scale_y_continuous(limits=c(0,max(output_dtt$topci)))
dtt_pectoral_subsample<-p

##
## Pelvic complete sample
##
set.seed(73)

# Prepare data
data<-pelvic_parameters
tree<-tree_pelvic
rownames(data)<-tree$tip.label
pca_data<-phyl.pca(tree,data,method = "BM")
dat<-pca_data$S; rownames(dat)<-tree$tip.label
tree<-treedata(tree,dat,sort=T,warnings=T)$phy
dat<-treedata(tree,dat,sort=T,warnings=T)$data

# DTT
disp<-dtt(tree,dat,index="avg.sq",nsim=10000,CI=0.95,plot=FALSE,calculateMDIp=F)
dtt_ma_time<-tree$root.time-(tree$root.time*disp$times)
dtt_sim_mean<-apply(disp$sim,1,mean)
dtt_sim_botCI<-dtt_sim_topCI<-vector()
for (i in 1:length(dtt_sim_mean)){
  dtt_sim_botCI[i]<-as.numeric(quantile(disp$sim[i,],0.025))
  dtt_sim_topCI[i]<-as.numeric(quantile(disp$sim[i,],0.975))
}
# output
output_dtt<-data.frame(cbind(dtt_ma_time,disp$dtt,dtt_sim_mean,dtt_sim_botCI,dtt_sim_topCI))
colnames(output_dtt)<-c("time","dtt","sim_mean","botci","topci")
test_text<-paste("Rand Inference",
                 "\n sim = 10,000",
                 "\n MDI =",round(disp$MDI,3),
                 "\n p =",formatC(getMDIp(disp)))
# visualize
p<-ggplot(output_dtt,aes(x=time,y=dtt)) +
  geom_ribbon(aes(ymin=botci,ymax=topci),fill="grey90") +
  geom_line(size=1.25) +
  geom_line(aes(y=sim_mean),linetype="dotted",size=1) +
  theme_bw() + theme(panel.border=element_blank(),panel.grid.major=element_blank(),panel.grid.minor=element_blank(),axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  scale_x_reverse() +
  xlab("Time (Mya)") + ylab("Pelvic DTT (complete sample)") +
  geom_vline(xintercept=419,color="red",linetype="dashed") + # First sarcopterigyans Benton M.J. and Donoghue P.C.J. 2006
  annotate("text",x=417,y=2.5,label="Sarcopterygii",hjust=0,size=4) +
  geom_vline(xintercept=397,color="green",linetype="dashed") + # Zachelmie tracks (Niedzwiedzki et al. 2010)
  annotate("text",x=395,y=2.25,label="Zachelmie tracks",hjust=0,size=4) +
  geom_vline(xintercept=355,color="blue",linetype="dashed") + # Crown group tetrapoda (Clack et al 2016)
  annotate("text",x=353,y=2,label="Tetrapoda",hjust=0,size=4) +
  geom_vline(xintercept=312.3,color="red",linetype="dashed") + # First amniotes Benton M.J. and Donoghue P.C.J. 2006
  annotate("text",x=310,y=1.75,label="Amniota",hjust=0,size=4) +
  annotate("text",x=250,y=1.75,label=test_text,hjust=0,size=3.5) +
  scale_y_continuous(limits=c(0,max(output_dtt$topci)))
dtt_pelvic_complete<-p

##
## Pelvic subsample
##
set.seed(73)

# Prerare data
data<-pelvic_subsample_parameters
tree<-tree_pectoral_pelvic
rownames(data)<-tree$tip.label
pca_data<-phyl.pca(tree,data,method = "BM")
dat<-pca_data$S; rownames(dat)<-tree$tip.label
tree<-treedata(tree,dat,sort=T,warnings=T)$phy
dat<-treedata(tree,dat,sort=T,warnings=T)$data

# DTT
disp<-dtt(tree,dat,index="avg.sq",nsim=10000,CI=0.95,plot=FALSE,calculateMDIp=F)
dtt_ma_time<-tree$root.time-(tree$root.time*disp$times)
dtt_sim_mean<-apply(disp$sim,1,mean)
dtt_sim_botCI<-dtt_sim_topCI<-vector()
for (i in 1:length(dtt_sim_mean)){
  dtt_sim_botCI[i]<-as.numeric(quantile(disp$sim[i,],0.025))
  dtt_sim_topCI[i]<-as.numeric(quantile(disp$sim[i,],0.975))
}
# output
output_dtt<-data.frame(cbind(dtt_ma_time,disp$dtt,dtt_sim_mean,dtt_sim_botCI,dtt_sim_topCI))
colnames(output_dtt)<-c("time","dtt","sim_mean","botci","topci")
test_text<-paste("Rand Inference",
                 "\n sim = 10,000",
                 "\n MDI =",round(disp$MDI,3),
                 "\n p =",formatC(getMDIp(disp)))
# visualize
p<-ggplot(output_dtt,aes(x=time,y=dtt)) +
  geom_ribbon(aes(ymin=botci,ymax=topci),fill="grey90") +
  geom_line(size=1.25) +
  geom_line(aes(y=sim_mean),linetype="dotted",size=1) +
  theme_bw() + theme(panel.border=element_blank(),panel.grid.major=element_blank(),panel.grid.minor=element_blank(),axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  scale_x_reverse() +
  xlab("Time (Mya)") + ylab("Pelvic DTT (subsample)") +
  geom_vline(xintercept=419,color="red",linetype="dashed") + # First sarcopterigyans Benton M.J. and Donoghue P.C.J. 2006
  annotate("text",x=417,y=2.5,label="Sarcopterygii",hjust=0,size=4) +
  geom_vline(xintercept=397,color="green",linetype="dashed") + # Zachelmie tracks (Niedzwiedzki et al. 2010)
  annotate("text",x=395,y=2.25,label="Zachelmie tracks",hjust=0,size=4) +
  geom_vline(xintercept=355,color="blue",linetype="dashed") + # Crown group tetrapoda (Clack et al 2016)
  annotate("text",x=353,y=2,label="Tetrapoda",hjust=0,size=4) +
  geom_vline(xintercept=312.3,color="red",linetype="dashed") + # First amniotes Benton M.J. and Donoghue P.C.J. 2006
  annotate("text",x=310,y=1.75,label="Amniota",hjust=0,size=4) +
  annotate("text",x=250,y=1.75,label=test_text,hjust=0,size=3.5) +
  scale_y_continuous(limits=c(0,max(output_dtt$topci)))
dtt_pelvic_subsample<-p

# Save figures
svg(filename=paste("extended/dtt/Figure 4. Disparity through time of pectoral and pelvic appendages(extended).svg"),width=8,height=8)
grid.arrange(arrangeGrob(dtt_pectoral_complete,dtt_pelvic_complete,ncol=2), # first row, 2 columns
             arrangeGrob(dtt_pectoral_subsample,dtt_pelvic_subsample,ncol=2), # second row, 2 columns
             nrow=2)                    # number of rows
dev.off()

#############################################################################################################


#############################################################################################################
# COMPARING PECTORAL AND PELVIC: PECTORAL-PELVIC SIMILARITY BOTTLENECKS
#############################################################################################################

# Prepare data
set.seed(73)
col<-c(rep("black",18),"blue")
tree<-tree_pectoral_pelvic
# get distance from bottleneck in absolute time
tetrapoda_time<-branching.times(tree)[findMRCA(tree,c("Tulerpeton","Mus"))-length(tree$tip.label)]
tips_time<-rev(FAD_LAD[row.names(FAD_LAD)%in%tree$tip.label,1])
# hypothesis
time_from_bottleneck<-abs(tetrapoda_time-tips_time)

## Nodes
variable<-"Nodes"
y<-pectoral_subsample_parameters[,which(parameter_names==variable)]
x<-pelvic_subsample_parameters[,which(parameter_names==variable)]
# get residulas for the identity line
a=1;b=-1;c=0
xi = (b*(b*x-a*y)-a*c) / (a^2+b^2)
yi = (a*(-b*x+a*y)-b*c) / (a^2+b^2)
y.res<-abs(a*x+b*y+c)/sqrt(a^2+b^2) # calculate absolute residuals
y.res<-(y.res-min(y.res))/(max(y.res)-min(y.res)) # normalization (from 0 to 1)
# test fin-bearing vs limb-bearing taxa y.res
print(variable)
grp<-as.factor(c(rep(1,13),rep(2,6)))
names(y.res)<-names(grp)<-tre<-tree$tip.label 
aov.phylo(y.res~grp, tree)
# test residuals~time agree with bottleneck
df<-as.data.frame(cbind(y.res,time_from_bottleneck),row.names=tree$tip.label)
pgls<-gls(y.res[-19]~time_from_bottleneck[-19],df[-19,],corPagel(1,phy=drop.tip(tree,19)))
# plot result
test_text<-paste(variable,
                 "\n Ho: slope = 0",
                 "\n slope =",formatC(summary(pgls)$tTable[2,1],format="e",digits=2),
                 "\n SE =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n t =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n p-value =",round(summary(pgls)$tTable[2,4],3))
pN<-ggplot(df, aes(time_from_bottleneck,y.res)) +
  geom_abline(intercept=pgls$coefficients[1],slope=pgls$coefficients[2],color="red",size=1) +
  geom_point(size=1.5,color=col) +
  theme_bw() + theme(axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  xlab("") + ylab("Pectoral-Pelvic Disparity") +
  annotate("text",x=100,y=0.8,label=test_text,hjust=0,size=3)
# Spearman correlation test using pics
pic.x <- pic(time_from_bottleneck, tree)
pic.y <- pic(y.res, tree)
sptest<-cor.test(pic.x,pic.y,method="spearman")
sptest$p.value

## Links
variable<-"Links"
y<-pectoral_subsample_parameters[,which(parameter_names==variable)]
x<-pelvic_subsample_parameters[,which(parameter_names==variable)]
# get residulas for the identity line
a=1;b=-1;c=0
xi = (b*(b*x-a*y)-a*c) / (a^2+b^2)
yi = (a*(-b*x+a*y)-b*c) / (a^2+b^2)
y.res<-abs(a*x+b*y+c)/sqrt(a^2+b^2) # calculate absolute residuals
y.res<-(y.res-min(y.res))/(max(y.res)-min(y.res)) # normalization (from 0 to 1)
# test fin-bearing vs limb-bearing taxa y.res
print(variable)
grp<-as.factor(c(rep(1,13),rep(2,6)))
names(y.res)<-names(grp)<-tre<-tree$tip.label 
aov.phylo(y.res~grp, tree)
# test residuals~time agree with bottleneck
df<-as.data.frame(cbind(y.res,time_from_bottleneck),row.names=tree$tip.label)
pgls<-gls(y.res[-19]~time_from_bottleneck[-19],df[-19,],corPagel(1,phy=drop.tip(tree,19)))
# plot result
test_text<-paste(variable,
                 "\n Ho: slope = 0",
                 "\n slope =",formatC(summary(pgls)$tTable[2,1],format="e",digits=2),
                 "\n SE =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n t =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n p-value =",round(summary(pgls)$tTable[2,4],3))
pK<-ggplot(df, aes(time_from_bottleneck,y.res)) +
  geom_abline(intercept=pgls$coefficients[1],slope=pgls$coefficients[2],color="red",size=1) +
  geom_point(size=1.5,color=col) +
  theme_bw() + theme(axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  xlab("") + ylab("") +
  annotate("text",x=100,y=0.8,label=test_text,hjust=0,size=3)
# Spearman correlation test using pics
pic.x <- pic(time_from_bottleneck, tree)
pic.y <- pic(y.res, tree)
sptest<-cor.test(pic.x,pic.y,method="spearman")
sptest$p.value

## Density
variable<-"Density"
y<-pectoral_subsample_parameters[,which(parameter_names==variable)]
x<-pelvic_subsample_parameters[,which(parameter_names==variable)]
# get residulas for the identity line
a=1;b=-1;c=0
xi = (b*(b*x-a*y)-a*c) / (a^2+b^2)
yi = (a*(-b*x+a*y)-b*c) / (a^2+b^2)
y.res<-abs(a*x+b*y+c)/sqrt(a^2+b^2) # calculate absolute residuals
y.res<-(y.res-min(y.res))/(max(y.res)-min(y.res)) # normalization (from 0 to 1)
# test fin-bearing vs limb-bearing taxa y.res
print(variable)
grp<-as.factor(c(rep(1,13),rep(2,6)))
names(y.res)<-names(grp)<-tre<-tree$tip.label 
aov.phylo(y.res~grp, tree)
# test residuals~time agree with bottleneck
df<-as.data.frame(cbind(y.res,time_from_bottleneck),row.names=tree$tip.label)
pgls<-gls(y.res[-19]~time_from_bottleneck[-19],df[-19,],corPagel(1,phy=drop.tip(tree,19)))
# plot result
test_text<-paste(variable,
                 "\n Ho: slope = 0",
                 "\n slope =",formatC(summary(pgls)$tTable[2,1],format="e",digits=2),
                 "\n SE =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n t =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n p-value =",round(summary(pgls)$tTable[2,4],3))
pD<-ggplot(df, aes(time_from_bottleneck,y.res)) +
  geom_abline(intercept=pgls$coefficients[1],slope=pgls$coefficients[2],color="red",size=1) +
  geom_point(size=1.5,color=col) +
  theme_bw() + theme(axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  xlab("") + ylab("Pectoral-Pelvic Disparity") +
  annotate("text",x=100,y=0.8,label=test_text,hjust=0,size=3)
# Spearman correlation test using pics
pic.x <- pic(time_from_bottleneck, tree)
pic.y <- pic(y.res, tree)
sptest<-cor.test(pic.x,pic.y,method="spearman")
sptest$p.value

## Clustering
variable<-"Clustering"
y<-pectoral_subsample_parameters[,which(parameter_names==variable)]
x<-pelvic_subsample_parameters[,which(parameter_names==variable)]
# get residulas for the identity line
a=1;b=-1;c=0
xi = (b*(b*x-a*y)-a*c) / (a^2+b^2)
yi = (a*(-b*x+a*y)-b*c) / (a^2+b^2)
y.res<-abs(a*x+b*y+c)/sqrt(a^2+b^2) # calculate absolute residuals
y.res<-(y.res-min(y.res))/(max(y.res)-min(y.res)) # normalization (from 0 to 1)
# test fin-bearing vs limb-bearing taxa y.res
print(variable)
grp<-as.factor(c(rep(1,13),rep(2,6)))
names(y.res)<-names(grp)<-tre<-tree$tip.label 
aov.phylo(y.res~grp, tree)
# test residuals~time agree with bottleneck
df<-as.data.frame(cbind(y.res,time_from_bottleneck),row.names=tree$tip.label)
pgls<-gls(y.res[-19]~time_from_bottleneck[-19],df[-19,],corPagel(1,phy=drop.tip(tree,19)))
# plot result
test_text<-paste(variable,
                 "\n Ho: slope = 0",
                 "\n slope =",formatC(summary(pgls)$tTable[2,1],format="e",digits=2),
                 "\n SE =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n t =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n p-value =",round(summary(pgls)$tTable[2,4],3))
pC<-ggplot(df, aes(time_from_bottleneck,y.res)) +
  geom_abline(intercept=pgls$coefficients[1],slope=pgls$coefficients[2],color="red",size=1) +
  geom_point(size=1.5,color=col) +
  theme_bw() + theme(axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  xlab("") + ylab("") +
  annotate("text",x=100,y=0.8,label=test_text,hjust=0,size=3)
# Spearman correlation test using pics
pic.x <- pic(time_from_bottleneck, tree)
pic.y <- pic(y.res, tree)
sptest<-cor.test(pic.x,pic.y,method="spearman")
sptest$p.value

## Path_length
variable<-"Path_length"
y<-pectoral_subsample_parameters[,which(parameter_names==variable)]
x<-pelvic_subsample_parameters[,which(parameter_names==variable)]
# get residulas for the identity line
a=1;b=-1;c=0
xi = (b*(b*x-a*y)-a*c) / (a^2+b^2)
yi = (a*(-b*x+a*y)-b*c) / (a^2+b^2)
y.res<-abs(a*x+b*y+c)/sqrt(a^2+b^2) # calculate absolute residuals
y.res<-(y.res-min(y.res))/(max(y.res)-min(y.res)) # normalization (from 0 to 1)
# test fin-bearing vs limb-bearing taxa y.res
print(variable)
grp<-as.factor(c(rep(1,13),rep(2,6)))
names(y.res)<-names(grp)<-tre<-tree$tip.label 
aov.phylo(y.res~grp, tree)
# test residuals~time agree with bottleneck
df<-as.data.frame(cbind(y.res,time_from_bottleneck),row.names=tree$tip.label)
pgls<-gls(y.res[-19]~time_from_bottleneck[-19],df[-19,],corPagel(1,phy=drop.tip(tree,19)))
# plot result
test_text<-paste(variable,
                 "\n Ho: slope = 0",
                 "\n slope =",formatC(summary(pgls)$tTable[2,1],format="e",digits=2),
                 "\n SE =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n t =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n p-value =",round(summary(pgls)$tTable[2,4],3))
pL<-ggplot(df, aes(time_from_bottleneck,y.res)) +
  geom_abline(intercept=pgls$coefficients[1],slope=pgls$coefficients[2],color="red",size=1) +
  geom_point(size=1.5,color=col) +
  theme_bw() + theme(axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  xlab("Time from the Tetrapoda Bottleneck (My)") + ylab("Pectoral-Pelvic Disparity") +
  annotate("text",x=100,y=0.8,label=test_text,hjust=0,size=3)
# Spearman correlation test using pics
pic.x <- pic(time_from_bottleneck, tree)
pic.y <- pic(y.res, tree)
sptest<-cor.test(pic.x,pic.y,method="spearman")
sptest$p.value

## Heterogeneity
variable<-"Heterogeneity"
y<-pectoral_subsample_parameters[,which(parameter_names==variable)]
x<-pelvic_subsample_parameters[,which(parameter_names==variable)]
# get residulas for the identity line
a=1;b=-1;c=0
xi = (b*(b*x-a*y)-a*c) / (a^2+b^2)
yi = (a*(-b*x+a*y)-b*c) / (a^2+b^2)
y.res<-abs(a*x+b*y+c)/sqrt(a^2+b^2) # calculate absolute residuals
y.res<-(y.res-min(y.res))/(max(y.res)-min(y.res)) # normalization (from 0 to 1)
# test fin-bearing vs limb-bearing taxa y.res
print(variable)
grp<-as.factor(c(rep(1,13),rep(2,6)))
names(y.res)<-names(grp)<-tre<-tree$tip.label 
aov.phylo(y.res~grp, tree)
# test residuals~time agree with bottleneck
df<-as.data.frame(cbind(y.res,time_from_bottleneck),row.names=tree$tip.label)
pgls<-gls(y.res[-19]~time_from_bottleneck[-19],df[-19,],corPagel(1,phy=drop.tip(tree,19)))
# plot result
test_text<-paste(variable,
                 "\n Ho: slope = 0",
                 "\n slope =",formatC(summary(pgls)$tTable[2,1],format="e",digits=2),
                 "\n SE =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n t =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n p-value =",round(summary(pgls)$tTable[2,4],3))
pH<-ggplot(df, aes(time_from_bottleneck,y.res)) +
  geom_abline(intercept=pgls$coefficients[1],slope=pgls$coefficients[2],color="red",size=1) +
  geom_point(size=1.5,color=col) +
  theme_bw() + theme(axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  xlab("Time from the Tetrapoda Bottleneck (My)") + ylab("") +
  annotate("text",x=100,y=0.8,label=test_text,hjust=0,size=3)
# Spearman correlation test using pics
pic.x <- pic(time_from_bottleneck, tree)
pic.y <- pic(y.res, tree)
sptest<-cor.test(pic.x,pic.y,method="spearman")
sptest$p.value

## Assortativity
variable<-"Assortativity"
y<-pectoral_subsample_parameters[,which(parameter_names==variable)]
x<-pelvic_subsample_parameters[,which(parameter_names==variable)]
# get residulas for the identity line
a=1;b=-1;c=0
xi = (b*(b*x-a*y)-a*c) / (a^2+b^2)
yi = (a*(-b*x+a*y)-b*c) / (a^2+b^2)
y.res<-abs(a*x+b*y+c)/sqrt(a^2+b^2) # calculate absolute residuals
y.res<-(y.res-min(y.res))/(max(y.res)-min(y.res)) # normalization (from 0 to 1)
# test fin-bearing vs limb-bearing taxa y.res
print(variable)
grp<-as.factor(c(rep(1,13),rep(2,6)))
names(y.res)<-names(grp)<-tre<-tree$tip.label 
aov.phylo(y.res~grp, tree)
# test residuals~time agree with bottleneck
df<-as.data.frame(cbind(y.res,time_from_bottleneck),row.names=tree$tip.label)
pgls<-gls(y.res[-19]~time_from_bottleneck[-19],df[-19,],corPagel(1,phy=drop.tip(tree,19)))
# plot result
test_text<-paste(variable,
                 "\n Ho: slope = 0",
                 "\n slope =",formatC(summary(pgls)$tTable[2,1],format="e",digits=2),
                 "\n SE =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n t =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n p-value =",round(summary(pgls)$tTable[2,4],3))
pA<-ggplot(df, aes(time_from_bottleneck,y.res)) +
  geom_abline(intercept=pgls$coefficients[1],slope=pgls$coefficients[2],color="red",size=1) +
  geom_point(size=1.5,color=col) +
  theme_bw() + theme(axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  xlab("Time from the Tetrapoda Bottleneck (My)") + ylab("") +
  annotate("text",x=100,y=0.8,label=test_text,hjust=0,size=3)
# Spearman correlation test using pics
pic.x <- pic(time_from_bottleneck, tree)
pic.y <- pic(y.res, tree)
sptest<-cor.test(pic.x,pic.y,method="spearman")
sptest$p.value

## Parcellation
variable<-"Parcellation"
y<-pectoral_subsample_parameters[,which(parameter_names==variable)]
x<-pelvic_subsample_parameters[,which(parameter_names==variable)]
# get residulas for the identity line
a=1;b=-1;c=0
xi = (b*(b*x-a*y)-a*c) / (a^2+b^2)
yi = (a*(-b*x+a*y)-b*c) / (a^2+b^2)
y.res<-abs(a*x+b*y+c)/sqrt(a^2+b^2) # calculate absolute residuals
y.res<-(y.res-min(y.res))/(max(y.res)-min(y.res)) # normalization (from 0 to 1)
# test fin-bearing vs limb-bearing taxa y.res
print(variable)
grp<-as.factor(c(rep(1,13),rep(2,6)))
names(y.res)<-names(grp)<-tre<-tree$tip.label 
aov.phylo(y.res~grp, tree)
# test residuals~time agree with bottleneck
df<-as.data.frame(cbind(y.res,time_from_bottleneck),row.names=tree$tip.label)
pgls<-gls(y.res[-19]~time_from_bottleneck[-19],df[-19,],corPagel(1,phy=drop.tip(tree,19)))
# plot result
test_text<-paste(variable,
                 "\n Ho: slope = 0",
                 "\n slope =",formatC(summary(pgls)$tTable[2,1],format="e",digits=2),
                 "\n SE =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n t =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n p-value =",round(summary(pgls)$tTable[2,4],3))
pP<-ggplot(df, aes(time_from_bottleneck,y.res)) +
  geom_abline(intercept=pgls$coefficients[1],slope=pgls$coefficients[2],color="red",size=1) +
  geom_point(size=1.5,color=col) +
  theme_bw() + theme(axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  xlab("Time from the Tetrapoda Bottleneck (My)") + ylab("") +
  annotate("text",x=100,y=0.8,label=test_text,hjust=0,size=3)
# Spearman correlation test using pics
pic.x <- pic(time_from_bottleneck, tree)
pic.y <- pic(y.res, tree)
sptest<-cor.test(pic.x,pic.y,method="spearman")
sptest$p.value

# Plot all
svg(filename=paste("extended/pecpel/Figure. Tetrapod bottleneck tests (extended).svg"),width=14,height=7)
grid.arrange(arrangeGrob(pN,pK,pD,pC,ncol=4), # first row, 2 columns
             arrangeGrob(pL,pH,pA,pP,ncol=4), # second row, 2 columns
             nrow=2)                    # number of rows
dev.off()

#############################################################################################################


